﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using Telerik.Windows.Controls.Charting;

namespace ZoomingAndScrollingDateTime
{
    public partial class MainPage : UserControl, INotifyPropertyChanged
    {
        public MainPage()
        {
            DataContext = this;
            InitializeComponent();

            RangeStart = 0.3;
            RangeEnd = 0.7;
            ScrollMode = "ScrollAndZoom";
            SeriesMapping mapping = new SeriesMapping();
            mapping.SeriesDefinition = new LineSeriesDefinition();
            mapping.ItemMappings.Add(new ItemMapping("Date", DataPointMember.XCategory));
            mapping.ItemMappings.Add(new ItemMapping("Value", DataPointMember.YValue));
            radChart.SeriesMappings.Add(mapping);


            radChart.DefaultView.ChartArea.EnableAnimations = false;
            radChart.DefaultView.ChartArea.AxisX.IsDateTime = true;
            radChart.DefaultView.ChartArea.AxisX.DefaultLabelFormat = "dd-MMM";
        }

        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string p)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(p));
            }
        }

        private List<ChartData> _data;
        public List<ChartData> Data
        {
            get
            {
                if (_data == null)
                {
                    Random r = new Random();
                    List<ChartData> data = new List<ChartData>();
                    for (int i = 0; i < 35; i++)
                    {
                        data.Add(new ChartData(DateTime.Now.AddDays(i), i));
                    }
                    _data = data;
                }
                return _data;
            }
        }

        private double _rangeStart;
        public double RangeStart
        {
            get { return _rangeStart; }
            set
            {
                _rangeStart = value;
                OnPropertyChanged("RangeStart");
            }
        }

        private double _rangeEnd;
        public double RangeEnd
        {
            get { return _rangeEnd; }
            set
            {
                _rangeEnd = value;
                OnPropertyChanged("RangeEnd");
            }
        }
        private string _scrollMode;
        public string ScrollMode
        {
            get { return _scrollMode; }
            set
            {
                _scrollMode = value;
                OnPropertyChanged("ScrollMode");
            }
        }

        private double _minZoomRange;
        private double MinZoomRange
        {
            get { return _minZoomRange; }
            set
            {
                _minZoomRange = value;
                OnPropertyChanged("MinZoomRange");
            }
        }
    }

    public class ChartData
    {
        public ChartData(DateTime date, double? value)
        {
            this.Date = date;
            this.Value = value;
        }

        public double? Value { get; set; }
        public DateTime Date { get; set; }
    }

}
